@@ -104,15 +104,24 @@ class MetaData:
     def __init__(self, log_dir, store):
         self.log_dir = log_dir
         self.store = store
+        self.metadata_writer = Writer(self.store)
 
     def load_logs(self):
         parsed_flattened = parse_logfiles(self.log_dir)
         return parsed_flattened
 
     def run(self):
-        metadata_writer = Writer(self.store)
         metadata_dict = self.load_logs()
-        metadata_writer.write(path="/", meta=metadata_dict, overwrite=False)
+        self.metadata_writer.write(path="/", meta=metadata_dict, overwrite=False)
+
+    def add_field(self, field_name, field_value):
+        self.metadata_writer.write(
+            path="/", meta={field_name: field_value}, overwrite=False
+        )
+
+    def add_fields(self, fields_values: dict):
+        for field, value in fields_values.items():
+            self.add_field(field, value)
 
 
 ########################### Old Objects ####################################
